==> beigesoft-accounting-weboio-1.1.6-sources.jar: beige-orm/sqlite/upgrade_5.sql <==
insert into DEBTORCREDITORCATEGORY(ITSNAME, ITSID, ITSVERSION) values ('Online buyers', 7771777, 1462867931627);
insert into TRADINGSETTINGS (ITSID, ITSVERSION, ISGOODSSTORE, DEFAULTCUSTOMERCATEGORY, REMEMBERUNAUTHORIZEDUSERFOR, ITEMSPERPAGE, MAXQUANTITYOFTOPLEVELCATALOGS, MAXQUANTITYOFBULKITEMS, COLUMNSCOUNT) values (1, 1462867931627, 1, 7771777, 0, 50, 5, 50, 2);
insert into SETTINGSADD (ITSID, ITSVERSION, RECORDSPERTRANSACTION) values (1, 1462867931627, 100);
alter table DEBTORCREDITOR add column REGEMAIL text;
alter table DEBTORCREDITOR add column REGADDRESS1 text;
alter table DEBTORCREDITOR add column REGADDRESS2 text;
alter table DEBTORCREDITOR add column REGZIP text;
alter table DEBTORCREDITOR add column REGCOUNTRY text;
alter table DEBTORCREDITOR add column REGSTATE text;
alter table DEBTORCREDITOR add column REGCITY text;
alter table DEBTORCREDITOR add column REGPHONE text;
alter table DEBTORCREDITOR add column TAXIDENTIFICATIONNUMBER text;
alter table ACCSETTINGS add column REGEMAIL text;
alter table ACCSETTINGS add column REGADDRESS1 text;
alter table ACCSETTINGS add column REGADDRESS2 text;
alter table ACCSETTINGS add column REGZIP text;
alter table ACCSETTINGS add column REGCOUNTRY text;
alter table ACCSETTINGS add column REGSTATE text;
alter table ACCSETTINGS add column REGCITY text;
alter table ACCSETTINGS add column REGPHONE text;
alter table ACCSETTINGS add column TAXIDENTIFICATIONNUMBER text;
update DATABASEINFO set DATABASEVERSION=5, DESCRIPTION='Beige Accounting DB version 5';

==> beigesoft-accounting-weboio-1.1.7-sources.jar: beige-orm/sqlite/upgrade_5.sql <==
insert into DEBTORCREDITORCATEGORY(ITSNAME, ITSID, ITSVERSION) values ('Online buyers', 7771777, 1462867931627);
insert into TRADINGSETTINGS (ITSID, ITSVERSION, DEFAULTCUSTOMERCATEGORY, REMEMBERUNAUTHORIZEDUSERFOR, ITEMSPERPAGE, MAXQUANTITYOFTOPLEVELCATALOGS, MAXQUANTITYOFBULKITEMS, COLUMNSCOUNT) values (1, 1462867931627, 7771777, 0, 50, 5, 50, 2);
insert into SETTINGSADD (ITSID, ITSVERSION, RECORDSPERTRANSACTION) values (1, 1462867931627, 100);
alter table DEBTORCREDITOR add column REGEMAIL text;
alter table DEBTORCREDITOR add column REGADDRESS1 text;
alter table DEBTORCREDITOR add column REGADDRESS2 text;
alter table DEBTORCREDITOR add column REGZIP text;
alter table DEBTORCREDITOR add column REGCOUNTRY text;
alter table DEBTORCREDITOR add column REGSTATE text;
alter table DEBTORCREDITOR add column REGCITY text;
alter table DEBTORCREDITOR add column REGPHONE text;
alter table DEBTORCREDITOR add column TAXIDENTIFICATIONNUMBER text;
alter table ACCSETTINGS add column REGEMAIL text;
alter table ACCSETTINGS add column REGADDRESS1 text;
alter table ACCSETTINGS add column REGADDRESS2 text;
alter table ACCSETTINGS add column REGZIP text;
alter table ACCSETTINGS add column REGCOUNTRY text;
alter table ACCSETTINGS add column REGSTATE text;
alter table ACCSETTINGS add column REGCITY text;
alter table ACCSETTINGS add column REGPHONE text;
alter table ACCSETTINGS add column TAXIDENTIFICATIONNUMBER text;
update DATABASEINFO set DATABASEVERSION=5, DESCRIPTION='Beige Accounting DB version 5';
